@@ -1,11 +1,12 @@
-__version__ = "3.1.7"
+__version__ = "v4.0.0"
 __description__ = "One-stop solution for HTTP(S) testing."
 
-# import firstly for monkey patch if needed
-from httprunner.ext.locust import main_locusts
+from httprunner.config import Config
 from httprunner.parser import parse_parameters as Parameters
 from httprunner.runner import HttpRunner
-from httprunner.testcase import Config, Step, RunRequest, RunTestCase
+from httprunner.step import Step
+from httprunner.step_request import RunRequest
+from httprunner.step_testcase import RunTestCase
 
 __all__ = [
     "__version__",
