@@ -27,10 +27,6 @@ class TeardownHooksFailure(MyBaseFailure):
     pass
 
 
-class NetworkFailure(MyBaseFailure):
-    pass
-
-
 """ error type exceptions
     these exceptions will mark test as error
 """
@@ -89,5 +85,4 @@ class TestcaseNotFound(NotFoundError):
 
 
 class SummaryEmpty(MyBaseError):
-    """ test result summary data is empty
-    """
+    """test result summary data is empty"""
