@@ -1,11 +1,8 @@
 import os
 from enum import Enum
-from typing import Any
-from typing import Dict, Text, Union, Callable
-from typing import List
+from typing import Any, Callable, Dict, List, Text, Union
 
-from pydantic import BaseModel, Field
-from pydantic import HttpUrl
+from pydantic import BaseModel, Field, HttpUrl
 
 Name = Text
 Url = Text
@@ -31,6 +28,16 @@ class MethodEnum(Text, Enum):
     PATCH = "PATCH"
 
 
+# configs for thrift rpc
+class TConfigThrift(BaseModel):
+    psm: Text = None
+    env: Text = None
+    cluster: Text = None
+    target: Text = None
+    include_dirs: List[Text] = None
+    thrift_client: Any = None
+
+
 class TConfig(BaseModel):
     name: Name
     verify: Verify = False
@@ -42,7 +49,8 @@ class TConfig(BaseModel):
     # teardown_hooks: Hooks = []
     export: Export = []
     path: Text = None
-    weight: int = 1
+    # configs for other protocols
+    thrift: TConfigThrift = None
 
 
 class TRequest(BaseModel):
@@ -74,6 +82,8 @@ class TStep(BaseModel):
     export: Export = []
     validators: Validators = Field([], alias="validate")
     validate_script: List[Text] = []
+    retry_times: int = 0
+    retry_interval: int = 0  # sec
 
 
 class TestCase(BaseModel):
@@ -87,7 +97,9 @@ class ProjectMeta(BaseModel):
     dot_env_path: Text = ""  # .env file path
     functions: FunctionsMapping = {}  # functions defined in debugtalk.py
     env: Env = {}
-    RootDir: Text = os.getcwd()  # project root directory (ensure absolute), the path debugtalk.py located
+    RootDir: Text = (
+        os.getcwd()
+    )  # project root directory (ensure absolute), the path debugtalk.py located
 
 
 class TestsMapping(BaseModel):
@@ -133,7 +145,7 @@ class ResponseData(BaseModel):
     cookies: Cookies
     encoding: Union[Text, None] = None
     content_type: Text
-    body: Union[Text, bytes, List, Dict]
+    body: Union[Text, bytes, List, Dict, None]
 
 
 class ReqRespData(BaseModel):
@@ -153,16 +165,35 @@ class SessionData(BaseModel):
     validators: Dict = {}
 
 
-class StepData(BaseModel):
+class StepResult(BaseModel):
     """teststep data, each step maybe corresponding to one request or one testcase"""
 
-    success: bool = False
     name: Text = ""  # teststep name
-    data: Union[SessionData, List['StepData']] = None
+    step_type: Text = ""  # teststep type, request or testcase
+    success: bool = False
+    data: Union[SessionData, List["StepResult"]] = None
+    elapsed: float = 0.0  # teststep elapsed time
+    content_size: float = 0  # response content size
     export_vars: VariablesMapping = {}
+    attachment: Text = ""  # teststep attachment
 
-        
-StepData.update_forward_refs()
+
+StepResult.update_forward_refs()
+
+
+class IStep(object):
+    def name(self) -> str:
+        raise NotImplementedError
+
+    def type(self) -> str:
+        raise NotImplementedError
+
+    def struct(self) -> TStep:
+        raise NotImplementedError
+
+    def run(self, runner) -> StepResult:
+        # runner: HttpRunner
+        raise NotImplementedError
 
 
 class TestCaseSummary(BaseModel):
@@ -172,7 +203,7 @@ class TestCaseSummary(BaseModel):
     time: TestCaseTime
     in_out: TestCaseInOut = {}
     log: Text = ""
-    step_datas: List[StepData] = []
+    step_results: List[StepResult] = []
 
 
 class PlatformInfo(BaseModel):
@@ -181,18 +212,6 @@ class PlatformInfo(BaseModel):
     platform: Text
 
 
-class TestCaseRef(BaseModel):
-    name: Text
-    base_url: Text = ""
-    testcase: Text
-    variables: VariablesMapping = {}
-
-
-class TestSuite(BaseModel):
-    config: TConfig
-    testcases: List[TestCaseRef]
-
-
 class Stat(BaseModel):
     total: int = 0
     success: int = 0
